@@ -1,6 +1,6 @@
 """A clean customisable Sphinx documentation theme."""
 
-__version__ = "2023.07.26"
+__version__ = "2023.08.19"
 
 import hashlib
 import logging
@@ -16,6 +16,7 @@ from pygments.style import Style
 from pygments.token import Text
 from sphinx.builders.html import StandaloneHTMLBuilder
 from sphinx.environment.adapters.toctree import TocTree
+from sphinx.errors import ConfigError
 from sphinx.highlighting import PygmentsBridge
 from sphinx.transforms.post_transforms import SphinxPostTransform
 
@@ -173,16 +174,9 @@ def _html_page_context(
     context: Dict[str, Any],
     doctree: Any,
 ) -> None:
-    if not isinstance(app.builder, StandaloneHTMLBuilder):
-        raise Exception(
-            "Furo is being used with a non-HTML builder. "
-            "If you're seeing this error, it is a symptom of a mistake in your "
-            "configuration."
-        )
-
     if "css_files" in context:
-        if "_static/styles/furo.css" not in context["css_files"]:
-            raise Exception(
+        if "_static/styles/furo.css" not in [c.filename for c in context["css_files"]]:
+            raise ConfigError(
                 "This documentation is not using `furo.css` as the stylesheet. "
                 "If you have set `html_style` in your conf.py file, remove it."
             )
@@ -227,14 +221,17 @@ def _html_page_context(
 
 def _builder_inited(app: sphinx.application.Sphinx) -> None:
     if "furo" in app.config.extensions:
-        raise Exception(
+        raise ConfigError(
             "Did you list 'furo' in the `extensions` in conf.py? "
             "If so, please remove it. Furo does not work with non-HTML builders "
             "and specifying it as an `html_theme` is sufficient."
         )
 
-    if not isinstance(app.builder, StandaloneHTMLBuilder):
-        raise Exception(
+    if not isinstance(app.builder, StandaloneHTMLBuilder) or app.builder.name not in {
+        "html",
+        "dirhtml",
+    }:
+        raise ConfigError(
             "Furo is being used as an extension in a non-HTML build. "
             "This should not happen."
         )
@@ -246,7 +243,6 @@ def _builder_inited(app: sphinx.application.Sphinx) -> None:
     app.add_css_file("styles/furo-extensions.css", priority=600)
 
     builder = app.builder
-    assert builder, "what?"
     assert (
         builder.highlighter is not None
     ), "there should be a default style known to Sphinx"
@@ -277,70 +273,7 @@ def _get_light_style(app: sphinx.application.Sphinx) -> Style:
 
 
 def _get_dark_style(app: sphinx.application.Sphinx) -> Style:
-    # number_of_hours_spent_figuring_this_out = 7
-    #
-    # Hello human in the future! This next block of code needs a bit of a story, and
-    # if you're going to touch it, remember to update the number above (or remove this
-    # comment entirely).
-    #
-    # Hopefully, you know that Sphinx allows extensions and themes to add configuration
-    # values via `app.add_config_value`. This usually lets users set those values from
-    # `conf.py` while allowing the extension to read from it and utilise that information.
-    # As any reasonable person who's written a Sphinx extension before, you would
-    # expect the following to work:
-    #
-    #     dark_style = app.config.pygments_dark_style
-    #
-    # Turns out, no. How dare you expect things to just work!? That stuff just returns
-    # the default value provided when calling `app.add_config_value`. Yes, even if you
-    # set it in `conf.py`. Why? Good question. :)
-    #
-    # The logic in Sphinx literally looks it up in the same mapping as what was
-    # manipulated by `add_config_value`, and there's no other spot where that value
-    # gets manipulated. I spent a bunch of time debugging how that class works, and...
-    # yea, I can't figure it out. There's multiple mappings floating around and bunch
-    # of manipulation being done for all kinds of things.
-    #
-    # The only place on the config object where I was able to find the user-provided
-    # value from `conf.py` is a private variable `self._raw_config`. Those values are
-    # supposed to get added to self.__dict__[...], and generally be accessible through
-    # the object's custom `__getattr__`.
-    #
-    # Anyway, after giving up on figuring out how to file a PR to fix this upstream, I
-    # started looking for hacky ways to get this without reaching into private
-    # variables. That quest led to a very simple conclusion: no, you can't do that.
-    #
-    # So, here we are: with the only option being to reach into the guts of the beast,
-    # and pull out the specific thing that's needed. This is obviously fragile though,
-    # so this is written with the assumption that any changes to Sphinx's config
-    # object's internals would correspond to the originally expected behaviour working.
-    # This is so that when any of Sphinx's internals change, this logic would basically
-    # fall back to the original behaviour and also print a warning, so that hopefully
-    # someone will report this. Maybe it'll all be fixed, and I can remove this whole
-    # hack and this giant comment.
-
-    # HACK: begins here
-    dark_style = None
-    try:
-        if (
-            hasattr(app.config, "_raw_config")
-            and isinstance(app.config._raw_config, dict)
-            and "pygments_dark_style" in app.config._raw_config
-        ):
-            dark_style = app.config._raw_config["pygments_dark_style"]
-    except (AttributeError, KeyError) as e:
-        logger.warning(
-            (
-                "Furo could not determine the value of `pygments_dark_style`. "
-                "Falling back to using the value provided by Sphinx.\n"
-                "Caused by %s"
-            ),
-            e,
-        )
-
-    if dark_style is None:
-        dark_style = app.config.pygments_dark_style
-
+    dark_style = app.config.pygments_dark_style
     return PygmentsBridge("html", dark_style).formatter_args["style"]
 
 
@@ -399,7 +332,7 @@ def _overwrite_pygments_css(
 
 def setup(app: sphinx.application.Sphinx) -> Dict[str, Any]:
     """Entry point for sphinx theming."""
-    app.require_sphinx("3.0")
+    app.require_sphinx("6.0")
 
     app.add_config_value(
         "pygments_dark_style", default="native", rebuild="env", types=[str]
